@@ -12,7 +12,7 @@ logger = logging.getLogger(__name__)
 
 def _get_keys(url_or_keys):
     if isinstance(url_or_keys, str) and url_or_keys.startswith('https://'):
-        logger.info("Getting jwk from {}...", url_or_keys)
+        logger.info("Getting jwk from %s...", url_or_keys)
         with urllib.request.urlopen(url_or_keys) as f:
             return json.loads(f.read().decode())
     else:
